@@ -14,6 +14,7 @@
 
 from django.forms import ValidationError
 from django.utils.translation import ugettext_lazy as _
+import yaml
 
 from horizon import exceptions
 from horizon import forms
@@ -89,7 +90,7 @@ class OnBoardVNF(forms.SelfHandlingForm):
 
     def handle(self, request, data):
         try:
-            toscal = data['tosca']
+            toscal = yaml.load(data['tosca'], Loader=yaml.SafeLoader)
             vnfd_name = data['name']
             vnfd_description = data['description']
             tosca_arg = {'vnfd': {'name': vnfd_name,
@@ -100,8 +101,7 @@ class OnBoardVNF(forms.SelfHandlingForm):
                              _('VNF Catalog entry %s has been created.') %
                              vnfd_instance['vnfd']['name'])
             return toscal
-        except Exception as e:
-            msg = _('Unable to create TOSCA. %s')
-            msg %= e.message.split('Failed validating', 1)[0]
-            exceptions.handle(request, message=msg)
+        except Exception:
+            msg = _('Unable to create TOSCA.')
+            exceptions.handle(request, msg)
             return False
